
#ifndef ARCHIVER_EXPORT_H
#define ARCHIVER_EXPORT_H

#ifdef ARCHIVER_STATIC_DEFINE
#  define ARCHIVER_EXPORT
#  define ARCHIVER_NO_EXPORT
#else
#  ifndef ARCHIVER_EXPORT
#    ifdef MauiKitArchiver4_EXPORTS
        /* We are building this library */
#      define ARCHIVER_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define ARCHIVER_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef ARCHIVER_NO_EXPORT
#    define ARCHIVER_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef ARCHIVER_DEPRECATED
#  define ARCHIVER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef ARCHIVER_DEPRECATED_EXPORT
#  define ARCHIVER_DEPRECATED_EXPORT ARCHIVER_EXPORT ARCHIVER_DEPRECATED
#endif

#ifndef ARCHIVER_DEPRECATED_NO_EXPORT
#  define ARCHIVER_DEPRECATED_NO_EXPORT ARCHIVER_NO_EXPORT ARCHIVER_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef ARCHIVER_NO_DEPRECATED
#    define ARCHIVER_NO_DEPRECATED
#  endif
#endif

#endif /* ARCHIVER_EXPORT_H */
